@@ -6,9 +6,9 @@
 #'
 #' @return Response from the server containing a list of all datasets available.
 #' The list contains 3 elements:
-#' - Total: Total number of datasets available (integer)
-#' - Page: Page of the result (integer)
-#' - Results: data concerning the datasets (data.frame)
+#' - total: Total number of datasets available (integer)
+#' - page: Page of the result (integer)
+#' - results: data concerning the datasets (data.frame)
 #' @export
 #' @family Datasets
 #' @examples
@@ -16,7 +16,7 @@
 #' get_datasets()
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_datasets <- function(token = Sys.getenv("HLIDAC_TOKEN")) {
@@ -50,7 +50,7 @@ get_datasets <- function(token = Sys.getenv("HLIDAC_TOKEN")) {
 #' get_dataset_metadata("ministri")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_dataset_metadata <- function(dataset_id, token = Sys.getenv("HLIDAC_TOKEN")) {
@@ -74,14 +74,14 @@ get_dataset_metadata <- function(dataset_id, token = Sys.getenv("HLIDAC_TOKEN"))
 #' @param dataset_id ID of dataset
 #' @param token Authorization token
 #' @param query Search query
-#' @param page Number of page
+#' @param page Number of page (Please note that if the page parameter exceeds 200, the function returns error)
 #' @param sort Sort by column
 #' @param desc Descending or ascending sorting
 #'
 #' @return list containing 3 elements:
-#' - Total: Total number of datasets available (integer)
-#' - Page: Page of the result (integer), equal to the `page` argument of the function
-#' - Results: Data.frame with data, columns vary depending on the dataset
+#' - total: Total number of datasets available (integer)
+#' - page: Page of the result (integer), equal to the `page` argument of the function
+#' - results: Data.frame with data, columns vary depending on the dataset
 #' @export
 #' @family Datasets
 #' @examples
@@ -90,7 +90,7 @@ get_dataset_metadata <- function(dataset_id, token = Sys.getenv("HLIDAC_TOKEN"))
 #' get_dataset_data("ministri", query = "Zeman", page = 1)
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_dataset_data <- function(dataset_id, token = Sys.getenv("HLIDAC_TOKEN"),
@@ -130,7 +130,7 @@ get_dataset_data <- function(dataset_id, token = Sys.getenv("HLIDAC_TOKEN"),
 #' }
 #' @seealso
 #' \code{\link{get_dataset_data}}
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_dataset_record_detail <- function(dataset_id, item_id,
@@ -156,7 +156,7 @@ get_dataset_record_detail <- function(dataset_id, item_id,
 #' Search subsidies
 #'
 #' @param query Search query
-#' @param page Page number
+#' @param page Page number (Please note that if the page parameter exceeds 200, the function returns error)
 #' @param sort Sorting of results, the available options are the following:
 #' - 0: order by relevance
 #' - 1: order by the date of signature, the most recent first
@@ -168,9 +168,9 @@ get_dataset_record_detail <- function(dataset_id, item_id,
 #' @param token Authorization token
 #'
 #' @return list containing 3 elements:
-#' - Total: Total number of datasets available (integer)
-#' - Page: Page of the result (integer), equal to the `page` argument of the function
-#' - Results: Data.frame with data, columns vary depending on the dataset
+#' - total: Total number of datasets available (integer)
+#' - page: Page of the result (integer), equal to the `page` argument of the function
+#' - results: Data.frame with data, columns vary depending on the dataset
 #' @export
 #' @family Subsidies
 #' @examples
@@ -178,7 +178,7 @@ get_dataset_record_detail <- function(dataset_id, item_id,
 #' search_subsidies("golf")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 search_subsidies <- function(query, page = 1, sort = NULL,
@@ -215,7 +215,7 @@ search_subsidies <- function(query, page = 1, sort = NULL,
 #' get_subsidy("deminimis-1000229862")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_subsidy <- function(id, token = Sys.getenv("HLIDAC_TOKEN")){
@@ -242,9 +242,9 @@ get_subsidy <- function(id, token = Sys.getenv("HLIDAC_TOKEN")){
 #' @param company_name Name of the company
 #' @param token Access token
 #' @return list with 3 elements:
-#' - ICO: ID number of the company
-#' - Jmeno: Name of the company
-#' - DatoveSchranky: Data post box - electronic repository for communication between
+#' - ico: ID number of the company
+#' - jmeno: Name of the company
+#' - datoveSchranky: Data post box - electronic repository for communication between
 #' public institutions and private companies/people
 #' @export
 #' @family Companies
@@ -253,7 +253,7 @@ get_subsidy <- function(id, token = Sys.getenv("HLIDAC_TOKEN")){
 #' get_company("Agrofert")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_company <- function(company_name, token = Sys.getenv("HLIDAC_TOKEN")) {
@@ -279,19 +279,19 @@ get_company <- function(company_name, token = Sys.getenv("HLIDAC_TOKEN")) {
 #' @param person_id Person's ID
 #' @param token Access token
 #' @return list with the following elements:
-#' - TitulPred: academic titles written before person's name
-#' - Jmeno: given name
-#' - Prijmeni: surname
-#' - TitulPo: academic titles written after person's name (if applicable)
-#' - Narozeni: date of birth
-#' - NameId: person's id
-#' - Profile: URL of profile at hlidacstatu.cz
-#' - Sponzoring: data.frame with data on sponsorship of political parties
+#' - titulPred: academic titles written before person's name
+#' - jmeno: given name
+#' - prijmeni: surname
+#' - titulPo: academic titles written after person's name (if applicable)
+#' - narozeni: date of birth
+#' - nameId: person's id
+#' - profile: URL of profile at hlidacstatu.cz
+#' - sponzoring: data.frame with data on sponsorship of political parties
 #' by the person
-#' - Udalosti: events related to the person such as party membership and
+#' - udalosti: events related to the person such as party membership and
 #' running in election, serving in political bodies and relations to private
 #' companies (shareholder, serving on a board)
-#' - SocialniSite: data.frame with data on social media accounts
+#' - socialniSite: data.frame with data on social media accounts
 #' @export
 #' @family Persons
 #' @examples
@@ -299,7 +299,7 @@ get_company <- function(company_name, token = Sys.getenv("HLIDAC_TOKEN")) {
 #' get_person("andrej-babis")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_person <- function(person_id, token = Sys.getenv("HLIDAC_TOKEN")) {
@@ -319,32 +319,31 @@ get_person <- function(person_id, token = Sys.getenv("HLIDAC_TOKEN")) {
   jsonlite::fromJSON(stringr::str_conv(response$content, "UTF-8"))
 }
 
-#' Get person details
+#' Search person
 #'
 #' @param query Search query for a person, required parameter
-#' @param party Search query for a political party
+#' @param page Page number
 #' @param token Access token
 #'
 #' @return data.frame with found persons with the following columns:
-#' - Jmeno: given name
-#' - Prijmeni: surname
-#' - Narozeni: date of birth
-#' - NameId: person's ID
-#' - Profile: URL of profile at hlidacstatu.cz
-#' - TitulPred: academic titles written before person's name
-#' - TitulPo: academic titles written after person's name
+#' - jmeno: given name
+#' - prijmeni: surname
+#' - narozeni: date of birth
+#' - nameId: person's ID
+#' - profile: URL of profile at hlidacstatu.cz
+#' - titulPred: academic titles written before person's name
+#' - titulPo: academic titles written after person's name
 #' @export
 #' @family Persons
 #' @examples
 #' \dontrun{
 #' search_person(query = "Kalousek")
-#' search_person(query = "Kalousek", party = "TOP 09")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
-search_person <- function(query, party = NULL,
+search_person <- function(query, page = NULL,
                           token = Sys.getenv("HLIDAC_TOKEN")){
   check_token(token)
   check_connection()
@@ -353,10 +352,75 @@ search_person <- function(query, party = NULL,
     usethis::ui_stop("Query is required.")
   }
 
+  response <- httr::GET(
+    "https://www.hlidacstatu.cz/api/v2/osoby/hledatFtx",
+    query = list(ftxDotaz = query,
+                 strana = page),
+    httr::add_headers(Authorization = token,
+                      user_agent)
+  )
+
+  if (response$status_code != 200) {
+    handle_error_response(response)
+  }
+
+  jsonlite::fromJSON(stringr::str_conv(response$content, "UTF-8"))
+}
+
+
+#' Search person by name and date of birth
+#'
+#' @param first_name Person's first name
+#' @param last_name Person's last name
+#' @param birth_date Person's date of birth (in YYYY-MM-DD format)
+#' @param ignore_diacritics Parameter indicating whether diacritics in names should be ignored (boolean)
+#' @param token Access token
+#'
+#' @return data.frame with found persons with the following columns:
+#' - jmeno: given name
+#' - prijmeni: surname
+#' - narozeni: date of birth
+#' - nameId: person's ID
+#' - profile: URL of profile at hlidacstatu.cz
+#' - titulPred: academic titles written before person's name
+#' - titulPo: academic titles written after person's name
+#' @export
+#' @family Persons
+#' @examples
+#' \dontrun{
+#' search_person_by_parameters(first_name = "Miroslav", last_name = "Kalousek",
+#' birth_date = "1960-12-17")
+#' }
+#' @seealso
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
+#'
+#' \url{https://www.hlidacstatu.cz/api/v1/doc}
+search_person_by_parameters <- function(first_name = NULL,
+                                        last_name = NULL,
+                                        birth_date = NULL,
+                                        ignore_diacritics = TRUE,
+                                        token = Sys.getenv("HLIDAC_TOKEN")){
+  check_token(token)
+  check_connection()
+
+  if (is.null(first_name)) {
+    usethis::ui_stop("first_name is required.")
+  }
+
+  if (is.null(last_name)) {
+    usethis::ui_stop("last_name is required.")
+  }
+
+  if (is.null(birth_date)) {
+    usethis::ui_stop("birth_date is required.")
+  }
+
   response <- httr::GET(
     "https://www.hlidacstatu.cz/api/v2/osoby/hledat",
-    query = list(dotaz = query,
-                 strana = party),
+    query = list(jmeno = first_name,
+                 prijmeni = last_name,
+                 datumNarozeni = birth_date,
+                 ignoreDiakritiku = ignore_diacritics),
     httr::add_headers(Authorization = token,
                       user_agent)
   )
@@ -375,13 +439,13 @@ search_person <- function(query, party = NULL,
 #' @param token Access token
 #' @return data.frame with data on persons' social accounts with the
 #' following columns:
-#' - TitulPred: academic titles written before person's name
-#' - Jmeno: given name
-#' - Prijmeni: surname
-#' - TitulPo: academic titles written after person's name
-#' - NameId: person's ID
-#' - Profile: URL of profile at hlidacstatu.cz
-#' - SocialniSite: data.frame with data on social accounts (Type of social media,
+#' - titulPred: academic titles written before person's name
+#' - jmeno: given name
+#' - prijmeni: surname
+#' - titulPo: academic titles written after person's name
+#' - nameId: person's ID
+#' - profile: URL of profile at hlidacstatu.cz
+#' - socialniSite: data.frame with data on social accounts (Type of social media,
 #' Id of the social media account, URL)
 #' @export
 #' @family Persons
@@ -390,7 +454,7 @@ search_person <- function(query, party = NULL,
 #' get_person_social(types = c("Twitter", "Instagram"))
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_person_social <- function(types, token = Sys.getenv("HLIDAC_TOKEN")){
@@ -416,7 +480,7 @@ get_person_social <- function(types, token = Sys.getenv("HLIDAC_TOKEN")){
 #' Search contract
 #'
 #' @param query Full-text search query
-#' @param page Page of results
+#' @param page Page of results (Please note that if the page parameter exceeds 200, the function returns error)
 #' @param sort Ordering of the results, the available options are the following:
 #' - 0: sort by relevance
 #' - 1: recently added contracts first
@@ -442,7 +506,7 @@ get_person_social <- function(types, token = Sys.getenv("HLIDAC_TOKEN")){
 #' search_contracts(query = "golf")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 #'
@@ -487,7 +551,7 @@ search_contracts <- function(query, token = Sys.getenv("HLIDAC_TOKEN"),
 #' get_contract(id = "1086905")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 #'
@@ -521,7 +585,7 @@ get_contract <- function(id, token = NULL) {
 #' get_contract_text(id = "1086905")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 #'
@@ -564,7 +628,7 @@ get_contract_text <- function(id, token = Sys.getenv("HLIDAC_TOKEN")) {
 #' get_websites()
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_websites <- function(token = Sys.getenv("HLIDAC_TOKEN")) {
@@ -589,9 +653,9 @@ get_websites <- function(token = Sys.getenv("HLIDAC_TOKEN")) {
 #' @param token Authorization token
 #'
 #' @return list with 2 elements:
-#' - Availability: data on availability of the website
+#' - availability: data on availability of the website
 #' including response time and HTTP status code every minute
-#' - SSL: assessment of the website's SSL server configuration
+#' - ssl: assessment of the website's SSL server configuration
 #'
 #' @export
 #' @examples
@@ -599,7 +663,7 @@ get_websites <- function(token = Sys.getenv("HLIDAC_TOKEN")) {
 #' get_website_detail(id = "10107")
 #' }
 #' @seealso
-#' \url{https://www.hlidacstatu.cz/api/v2/swagger/index}
+#' \url{https://www.hlidacstatu.cz/swagger/index.html}
 #'
 #' \url{https://www.hlidacstatu.cz/api/v1/doc}
 get_website_detail <- function(id, token = Sys.getenv("HLIDAC_TOKEN")) {
